@@ -26,7 +26,7 @@ class HabitJewelDb:
 
         # Create the database
         if os.path.exists(db_file):
-            print 'checking database schema version'
+            print 'Checking database schema version'
             self.conn = sqlite3.connect(db_file)
             self.check_and_upgrade_schema(db_file, code_schema_ver)
         else:
@@ -461,16 +461,46 @@ class HabitJewelDb:
              ORDER BY major DESC
                    , minor DESC
             """)
-    
+
         # Get the highest version only
         row = cursor.fetchone()
         db_schema_ver = str(row[0]) + '.' + str(row[1])
         cursor.close()
         return db_schema_ver
-    
-    
-    def check_and_upgrade_schema(self, db_file, code_schema_ver):
+
+
+    def fix_habits_with_null_ids(self):
+        print 'Checking for habits with NULL ids'
+        cursor = self.conn.execute(
+            """
+            SELECT COUNT(*)
+              FROM habits
+             WHERE id IS NULL
+            """)
+
+        row = cursor.fetchone()
+        cursor.close()
+
+        print str(row[0]) + ' habits with NULL ids found'
         
+        if str(row[0]) == str(0):
+            return
+
+        self.conn.execute(
+            """
+            UPDATE habits
+               SET id = ROWID
+             WHERE id IS NULL
+            """)
+
+        self.conn.commit()
+
+
+    def check_and_upgrade_schema(self, db_file, code_schema_ver):
+
+        # Check for habits with null ids and assign them valid ids
+        self.fix_habits_with_null_ids()
+
         db_schema_ver = self.get_current_schema_version()
         if db_schema_ver == code_schema_ver:
             print 'Database schema version (' + db_schema_ver + ') is up to date for this version'
@@ -485,11 +515,11 @@ class HabitJewelDb:
             elif db_schema_ver == '0.6':
                 self.upgrade_schema_0_6_to_0_7(db_file, db_schema_ver, code_schema_ver)
                 db_schema_ver = self.get_current_schema_version()
-    
+
             elif db_schema_ver == '0.7':
                 self.upgrade_schema_0_7_to_0_8(db_file, db_schema_ver, code_schema_ver)
                 db_schema_ver = self.get_current_schema_version()
-    
+
             else:
                 print 'No upgrade method available for Schema version ' + db_schema_ver
                 return False
@@ -503,10 +533,10 @@ class HabitJewelDb:
 
     def upgrade_schema_0_4_to_0_6(self, db_file, db_schema_ver, code_schema_ver):
         self.backup_database(db_file, db_schema_ver)
-        
+
         self.conn = sqlite3.connect(db_file)
         print 'Upgrading database schema to version ' + code_schema_ver + '...'
-        
+
         # Remove points column from habits audit table
         cursor = self.conn.executescript(
         """
@@ -665,10 +695,10 @@ class HabitJewelDb:
 
     def upgrade_schema_0_7_to_0_8(self, db_file, db_schema_ver, code_schema_ver):
         self.backup_database(db_file, db_schema_ver)
-        
+
         self.conn = sqlite3.connect(db_file)
         print 'Upgrading database schema to version ' + code_schema_ver + '...'
-        
+
         # Remove PRIMARY KEY option to id column in habits table
         cursor = self.conn.executescript(
         """
